==> s-postgray-0.8.1.tar.gz: s-postgray-0.8.1/include/su/random.h <==
/*@ Random number generator.
 *
 * Copyright (c) 2001 - 2023 Steffen Nurpmeso <steffen@sdaoden.eu>.
 * SPDX-License-Identifier: ISC
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef su_RANDOM_H
#define su_RANDOM_H
#include <su/code.h>
#define su_HEADER
#include <su/code-in.h>
C_DECL_BEGIN
struct su_random;
/* random {{{ */
enum su_random_type{
	su_RANDOM_TYPE_NONE,
	su_RANDOM_TYPE_R,
	su_RANDOM_TYPE_P,
	su_RANDOM_TYPE_SP,
	su_RANDOM_TYPE_VSP
};
typedef boole (*su_random_generate_fun)(void **cookie, void *buf, uz len);
struct su_random{
	BITENUM_IS(u8,su_random_type) rm_type;
	u8 rm_flags;
	u8 rm_ro1;
	u8 rm_ro2;
	u32 rm_reseed_after;
	u32 rm_reseed_next;
	u32 rm_bytes;
	void *rm_vp;
	void *rm_vsp_cookie;
};
EXPORT s32 su_random_create(struct su_random *self, enum su_random_type type, u32 estate);
EXPORT void su_random_gut(struct su_random *self);
EXPORT boole su_random_seed(struct su_random *self, struct su_random *with_or_nil);
EXPORT boole su_random_generate(struct su_random *self, void *buf, uz len);
EXPORT s32 su_random_vsp_install(su_random_generate_fun on_generate, u32 estate);
EXPORT s32 su_random_builtin_generate(void *buf, uz len, u32 estate);
EXPORT boole su_random_builtin_seed(boole seeder);
EXPORT boole su_random_builtin_set_reseed_after(boole seeder, u32 reseed_after);
/* }}} */
C_DECL_END
#include <su/code-ou.h>
#endif /* su_RANDOM_H */
/* s-itt-mode */

==> s-postgray-0.8.3.tar.gz: s-postgray-0.8.3/include/su/random.h <==
/*@ Random number generator.
 *
 * Copyright (c) 2001 - 2024 Steffen Nurpmeso <steffen@sdaoden.eu>.
 * SPDX-License-Identifier: ISC
 *
 * Permission to use, copy, modify, and/or distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#ifndef su_RANDOM_H
#define su_RANDOM_H
#include <su/code.h>
#define su_HEADER
#include <su/code-in.h>
C_DECL_BEGIN
struct su_random;
/* random {{{ */
enum su_random_type{
	su_RANDOM_TYPE_NONE,
	su_RANDOM_TYPE_R,
	su_RANDOM_TYPE_P,
	su_RANDOM_TYPE_SP,
	su_RANDOM_TYPE_VSP
};
typedef boole (*su_random_generate_fun)(void **cookie, void *buf, uz len);
struct su_random{
	BITENUM(u8,su_random_type) rm_type;
	u8 rm_flags;
	u8 rm_ro1;
	u8 rm_ro2;
	u32 rm_reseed_after;
	u32 rm_reseed_next;
	u32 rm_bytes;
	void *rm_vp;
	void *rm_vsp_cookie;
};
EXPORT s32 su_random_create(struct su_random *self, enum su_random_type type, u32 estate);
EXPORT void su_random_gut(struct su_random *self);
EXPORT boole su_random_seed(struct su_random *self, struct su_random *with_or_nil);
EXPORT boole su_random_generate(struct su_random *self, void *buf, uz len);
EXPORT s32 su_random_vsp_install(su_random_generate_fun on_generate, u32 estate);
EXPORT s32 su_random_builtin_generate(void *buf, uz len, u32 estate);
EXPORT boole su_random_builtin_seed(boole seeder);
EXPORT boole su_random_builtin_set_reseed_after(boole seeder, u32 reseed_after);
/* }}} */
C_DECL_END
#include <su/code-ou.h>
#endif /* su_RANDOM_H */
/* s-itt-mode */
